<?php

add_action("init"       ,"wp_simple_geo_statistic_create_database");
add_action("admin_menu"                 ,"wp_simple_geo_statistic_register_menu",9999);
add_action("wp_simple_geo_statistic_update" ,"wp_simple_geo_statistic_update",1,3);

/**
 * Create database
 * @return [type] [description]
 */
function wp_simple_geo_statistic_create_database()
{
    global $wpdb;

    $charset    = $wpdb->get_charset_collate();

    ob_start();

    ?>
    CREATE TABLE IF NOT EXISTS `<?= $wpdb->prefix; ?>wp_simple_geo_statistic` (
        `id` int(11) NOT NULL AUTO_INCREMENT,
        `post_ID`  int(11) NOT NULL,
        `shortkey` varchar(255) NOT NULL,
        `content` text NOT NULL,
        `show_in` text NOT NULL,
        `hide_in` text NOT NULL,
        `first_show` int(11) NOT NULL,
        `last_show` int(11) NOT NULL,
        `call` int(11) NOT NULL,
        PRIMARY KEY (`id`)
    ) <?= $charset; ?>
    <?php

    $query = ob_get_contents();
    ob_end_clean();

    $wpdb->query($query);
}

/**
 * Register to admin menu
 * @return [type] [description]
 */
function wp_simple_geo_statistic_register_menu()
{
    add_submenu_page("crbn-wp-simple-geo.php"   ,__("Statistic","wp_simple_geo"),__("Statistic","wp_simple_geo"),"manage_options",
    "wp-simple-geo-statistic","wp_simple_geo_statistic_page");
}

function wp_simple_geo_statistic_update($atts,$post,$content)
{
    global $wpdb;
    $table  = $wpdb->prefix."wp_simple_geo_statistic";

    $shortkey   = hash("sha256",$post->ID.":::".implode(":::",$atts).":::".$content,false);

    $query  = "SELECT * FROM ".$table." ".
              "WHERE post_ID = '".$post->ID."' AND shortkey='".$shortkey."'";

    $data   = $wpdb->get_row($query,ARRAY_A);

    if($data) :
        $wpdb->update($table,array(
            "last_show"     => time(),
            "call"          => $data["call"] + 1
        ),array(
            "post_ID"   => $post->ID,
            "shortkey"  => $shortkey
        ));
    else :
        $wpdb->insert($table,array(
            "post_ID"   => $post->ID,
            "shortkey"  => $shortkey,
            "content"   => $content,
            "show_in"   => serialize(array(
                "country"   => $atts["show_country"],
                "region"    => $atts["show_region"],
                "city"      => $atts["show_city"]
            )),
            "hide_in"   => serialize(array(
                "country"   => $atts["hide_country"],
                "region"    => $atts["hide_region"],
                "city"      => $atts["hide_city"]
            )),
            "first_show"    => time(),
            "last_show"     => time(),
            "call"          => 1
        ));
    endif;
}

/**
 * Display statistic page
 * @return [type] [description]
 */
function wp_simple_geo_statistic_page()
{
    global $wpdb;
    $table  = $wpdb->prefix."wp_simple_geo_statistic";

    $query  = "SELECT * FROM ".$table." ".
              "ORDER BY last_show DESC ";

    $data   = $wpdb->get_results($query,ARRAY_A);

    ?>
    <div class="wrap">
        <h2><?php _e("Statistic","wp_simple_geo"); ?></h2>
        <table class="wp-list-table widefat fixed striped comments">
            <thead>
                <tr>
                    <th><?php _e("Post","wp_simple_geo"); ?></th>
                    <th width="30%"><?php _e("Content","wp_simple_geo"); ?></th>
                    <th width="10%"><?php _e("First triggered","wp_simple_geo"); ?></th>
                    <th width="10%"><?php _e("Last triggered","wp_simple_geo"); ?></th>
                    <th><?php _e("Show in","wp_simple_geo"); ?></th>
                    <th><?php _e("Hide in","wp_simple_geo"); ?></th>
                    <th width="3%" style="text-align:center;"><?php _e("Called","wp_simple_geo"); ?></th>
                </tr>
            </thead>
            <tbody>
            <?php foreach((array) $data as $dt) :
                $post = get_post($dt["post_ID"]);
                $shows = unserialize($dt["show_in"]);
                $hides = unserialize($dt["hide_in"]);
            ?>
            <tr>
                <td><?= $post->post_title; ?></td>
                <td><?= $dt["content"]; ?></td>
                <td><?= date("Y-m-d H:i",$dt["first_show"]); ?></td>
                <td><?= date("Y-m-d H:i",$dt["last_show"]); ?></td>
                <td><?php
                foreach((array) $shows as $title => $show) :
                    if(!empty($show)) :
                        echo strtoupper($title)." : ".$show."<br />";
                    endif;
                endforeach;
                ?></td>
                <td><?php
                foreach((array) $hides as $title =>  $hide) :
                    if(!empty($hide)) :
                        echo strtoupper($title)." : ".$hide."<br />";
                    endif;
                endforeach;
                ?></td>
                <td style="text-align:center;"><?= $dt["call"]; ?></td>
            </tr>
            <?php endforeach; ?>
            </tbody>
        </table>
    </div>
    <?php
}
