<?php
/**
Plugin Name: WP Simple Geo ( Lite edition )
Plugin URI: #
Description: Display content depends on visitor location. Filter by region and city only in PRO VERSION
Author: Insta Team
Version: 1.0
Author URI: #
Text Domain: wp_simple_geo
*/
global $wp_simple_geo;

add_action('wp'                     ,'wp_simple_geo_detect');
add_action('wp_head'                ,'wp_simple_geo_css');
add_action('wp_footer'              ,'wp_simple_geo_footer');
add_action('carbon_register_fields' ,'wp_simple_geo_carbon_fields');

function wp_simple_geo_carbon_fields() {
    include_once(dirname(__FILE__) . '/inc/setting.php');
}

if(!class_exists('Carbon_Fields\\Container')) :
    require_once('carbon-fields/carbon-fields-plugin.php');
endif;

/**
 * Detect current user cookie
 * @return [type] [description]
 */
function wp_simple_geo_detect()
{
    global $wp_simple_geo;

    $var        = wp_simple_geo_generate_var();
    $debug      = carbon_get_theme_option('wp_simple_geo_debug');

    if(
        !isset($_COOKIE[$var]) || empty($_COOKIE[$var]) ||
        (current_user_can('manage_options') && $debug )
    ) :

        $data       = wp_simple_geo_get_data();

        if($data) :
            if(!(current_user_can('manage_options') && $debug )) :
                setcookie( $var, $data, time() +  (3 * 3600), COOKIEPATH, COOKIE_DOMAIN , false);
            endif;

            $wp_simple_geo  = json_decode($data,1);
        endif;

    else :
        $wp_simple_geo  = json_decode(stripslashes($_COOKIE[$var]),1);

    endif;

    return $wp_simple_geo;
}

/**
 * Generate random string by current worpress salt
 * @return string   random string
 */
function wp_simple_geo_generate_var()
{
    return 'CELITE'.substr(md5(wp_salt('nonce')),0,12);
}

/**
 * Get current user ip address
 * @return [type] [description]
 */
function wp_simple_geo_get_ip_address()
{
    $ipaddress = '';

    if (getenv('HTTP_CLIENT_IP')) :
        $ipaddress = getenv('HTTP_CLIENT_IP');
    elseif(getenv('HTTP_X_FORWARDED_FOR')) :
        $ipaddress = getenv('HTTP_X_FORWARDED_FOR');
    elseif(getenv('HTTP_X_FORWARDED')) :
        $ipaddress = getenv('HTTP_X_FORWARDED');
    elseif(getenv('HTTP_FORWARDED_FOR')) :
        $ipaddress = getenv('HTTP_FORWARDED_FOR');
    elseif(getenv('HTTP_FORWARDED')) :
       $ipaddress = getenv('HTTP_FORWARDED');
    elseif(getenv('REMOTE_ADDR')) :
        $ipaddress = getenv('REMOTE_ADDR');
    endif;

    return $ipaddress;
}

/**
 * Get
 * @param  [type] $ipaddress [description]
 * @return [type]            [description]
 */
function wp_simple_geo_get_data()
{
    $geodata    = array();
    $debug      = carbon_get_theme_option('wp_simple_geo_debug');
    $static_ip  = carbon_get_theme_option('wp_simple_geo_ip');
    $current_ip = wp_simple_geo_get_ip_address();

    $ip     = ($debug && !empty($static_ip)) ? $static_ip : $current_ip;

    $data   = wp_remote_get("http://www.geoplugin.net/php.gp?ip=".$ip);

    if($data["response"]["code"] != "403") :
        $data       = unserialize($data["body"]);
        $geodata    = array(
            "continent"     => strtoupper($data["geoplugin_continentCode"]),
            "country"       => strtoupper($data["geoplugin_countryCode"]),
            // "region"        => strtoupper($data["geoplugin_regionName"]),
            // "city"          => strtoupper($data["geoplugin_city"])
        );

        $geodata    = json_encode($geodata);
    elseif($debug) :

        $geodata    = array(
            "continent" => "AS",
            "country"   => "ID",
            // "region"    => strtoupper("Jakarta"),
            // "city"      => strtoupper("Jakarta")
        );
        $geodata    = json_encode($geodata);
    else :
        $geodata    = false;
    endif;

    return $geodata;
}

/**
 * Debugging purpose only
 * @return [type] [description]
 */
function wp_simple_geo_debug()
{
    ?><pre><?php
    print_r(func_get_args());
    ?></pre><?php
}

/**
 * Display CSS style
 * @return [type] [description]
 */
function wp_simple_geo_css()
{
    ?>
    <style media="screen">
        .orange-geolocation-debug {
            position    : fixed;
            bottom      : 20px;
            right       : 20px;
            padding     : 20px;
            background  : rgba(0,0,0,0.7);
            color       : white;
            font-size   : 10px;
        }
    </style>
    <?php
}

/**
 * Add custom script into footer
 * @return [type] [description]
 */
function wp_simple_geo_footer()
{
    global $wp_simple_geo;
    $debug      = carbon_get_theme_option('wp_simple_geo_debug');
    $var        = wp_simple_geo_generate_var();

    if($debug) :
        $data   = $wp_simple_geo;
    ?>
    <div class="orange-geolocation-debug">
        Debug visitor data : <br /><br />
    <?php
        foreach((array)$data as $key => $value) :
            echo $key.' = '.$value.'<br />';
        endforeach;
    ?>
    </div>
    <?php
    endif;
}

require_once(dirname(__FILE__)."/inc/editor-button.php");
require_once(dirname(__FILE__)."/inc/statistic.php");
require_once(dirname(__FILE__)."/inc/shortcode.php");
