<?php

add_action("init"                       ,"wp_simple_geo_editor_buttons");
add_action("admin_enqueue_scripts"      ,"wp_simple_geo_admin_css_js");
add_action("admin_footer"                   ,"wp_simple_geo_form_display");
add_action("wp_ajax_wp_simple_geo_shortcode"    ,"wp_simple_geo_shortcode_generate");

/**
 * Call tinymce custom buttons
 * @return [type] [description]
 */
function wp_simple_geo_editor_buttons()
{
    add_filter("mce_external_plugins"   ,"wp_simple_geo_add_editor_buttons");
    add_filter("mce_buttons"            ,"wp_simple_geo_register_editor_buttons");
}

/**
 * Add custom buttons JS function into tinymce
 * @param [type] $plugins [description]
 */
function wp_simple_geo_add_editor_buttons($plugins)
{
    $plugins["wp_simple_geo"]    = plugin_dir_url(dirname(__FILE__))."assets/js/tinymce.js";
    return $plugins;
}

/**
 * Set CSS and JS for admin
 * @return [type] [description]
 */
function wp_simple_geo_admin_css_js()
{
    global $pagenow;

    wp_register_style("wp_simple_geo-admin" ,plugin_dir_url(dirname(__FILE__))."assets/css/admin-style.css");
    wp_register_style("selectize"       ,plugin_dir_url(dirname(__FILE__))."assets/css/selectize.css");

    wp_register_script("selectize"          ,plugin_dir_url(dirname(__FILE__))."assets/js/selectize.js",array("jquery"));
    wp_register_script("wp_simple_geo-admin"    ,plugin_dir_url(dirname(__FILE__))."assets/js/admin-script.js",array("selectize"),NULL,true);

    wp_localize_script("wp_simple_geo-admin","wp_simple_geo",array(
        'url'    => plugin_dir_url(dirname(__FILE__)),
        'title'  => "WP Simple Geo"
    ));

    if($pagenow == "post.php" || $pagenow == "post-new.php") :
        wp_enqueue_style("wp_simple_geo-admin");
        wp_enqueue_style("selectize");

        wp_enqueue_script("wp_simple_geo-admin");
    endif;
}

/**
 * Add custon button into tinymce editor
 * @param  [type] $buttons [description]
 * @return [type]          [description]
 */
function wp_simple_geo_register_editor_buttons($buttons)
{
    array_push($buttons,"wp_simple_geo");
    return $buttons;
}

/**
 * Init form
 * @return [type] [description]
 */
function wp_simple_geo_form_display()
{
    global $pagenow;

    if($pagenow == "post.php" || $pagenow == "post-new.php") :
        $list_countries     = (include "list-countries.php");
    ?>
    <div id="wp_simple_geo_holder">
        <div class="wp_simple_geo">
            <textarea class="wp_simple_geo_content"></textarea>
            <h2><?php _e("Show selected content in","wp_simple_geo"); ?></h2>
            <table class="form-table form-show">
            	<tbody>
                    <tr class="country">
                        <th><label for="country"><?php _e("Country","wp_simple_geo"); ?></label></th>
                        <td>
                            <select name="show_country" class="insta-field country-list" multiple="multiple">
                            <?php foreach((array) $list_countries as $id => $country) : ?>
                                <option value="<?= $id; ?>"><?= $country; ?></option>
                            <?php endforeach; ?>
                            </select>
                        </td>
                    </tr>
                    <tr class="region">
                        <th><label for="region"><?php _e("Region","wp_simple_geo"); ?></label></th>
                        <td><input type="text" class="insta-field selectize" name="show_region" /></td>
                    </tr>
                    <tr class="city">
                        <th><label for="city"><?php _e("City","wp_simple_geo"); ?></label></th>
                        <td><input type="text" class="insta-field selectize" name="show_city" /></td>
                    </tr>
                </tbody>
            </table>
            <h3><?php _e("Hide selected content in","wp_simple_geo"); ?></h2>
            <table class="form-table form-hide">
            	<tbody>
                    <tr class="country">
                        <th><label for="country"><?php _e("Country","wp_simple_geo"); ?></label></th>
                        <td>
                            <select name="hide_country" class="insta-field country-list" multiple="multiple">
                            <?php foreach((array) $list_countries as $id => $country) : ?>
                                <option value="<?= $id; ?>"><?= $country; ?></option>
                            <?php endforeach; ?>
                            </select>
                        </td>
                    </tr>
                    <tr class="region">
                        <th><label for="region"><?php _e("Region","wp_simple_geo"); ?></label></th>
                        <td><input type="text" class="insta-field selectize" name="hide_region" /></td>
                    </tr>
                    <tr class="city">
                        <th><label for="city"><?php _e("City","wp_simple_geo"); ?></label></th>
                        <td><input type="text" class="insta-field selectize" name="hide_city" /></td>
                    </tr>
                </tbody>
            </table>
            <p class="submit">
                <input name="submit"  class="button button-primary" value="<?php _e("Generate Shortcode","wp_simple_geo"); ?>" type="button">
            </p>
        </div>
    </div>
    <?php
    endif;
}

/**
 * Shortcode generate
 * @return [type] [description]
 */
function wp_simple_geo_shortcode_generate()
{
    if(isset($_POST["input"]) && is_array($_POST["input"]) && count($_POST["input"]) > 0) :
        $input  = $_POST["input"];
        $params = [];

        foreach((array) $input as $in) :
            $value      = (is_array($in["value"])) ? implode(",",$in["value"]) : $in["value"];
            $params[]   = $in["name"]."='".$value."'";
        endforeach;

        ?>[wp_simple_geo <?= implode(" ",$params); ?>]<?= isset($_POST["text"]) ? stripslashes($_POST["text"]) : ""; ?>[/wp_simple_geo]<?php
    endif;
    exit();
}
